#!/usr/bin/env python3
"""
ROS service caller
"""
import rospy
"""
Similarly to service provider, we need to import service and the request,
response message definitions.
"""
from incredible_package.srv import Random, RandomRequest, RandomResponse
"""
Next, we import a Pythonic function to pause code execution. This code
is technically not a ROS node (see that there is no "rospy.init_node" call).
That is why we are not using rospy.Rate.
Warning! The "time.sleep" behaves differently from "rate.sleep"!
Most importantly, time.sleep pauses for the specified time, while rate.sleep
pauses for as long as is needed to keep the specified rate (frequency).
That is, it takes code execution time into account when computing
the sleep time.
"""
from time import sleep

# Always store service names and similar things into variables.
# Ideally, you would have service and topic names in ROS parameters,
# so when you want to change them later on you don't have to go through
# all your code and change every occurrance.
SERVICE_NAME = 'generate_number'

if __name__ == '__main__':
    """Next line of code holds the code execution until the specified
    service is advertized (by some other node) in ROS.
    This is very usefull for several reasons. One of them being that
    if you try to create service proxy for a non-existing service,
    you get an error.
    """
    rospy.wait_for_service(SERVICE_NAME)  # wait till the service is up
    """
    Once the service is up, we can create a service proxy - i.e. the object
    through which you can call the service.
    """
    generatorService = rospy.ServiceProxy(SERVICE_NAME, Random)
    while not rospy.is_shutdown():
        response = generatorService.call()  # call the service (no request message)
        print('Called the {} service, received '
              'response: {}'.format(SERVICE_NAME, response.randNumber))  # print response
        sleep(1)  # sleep for one second
