#!/usr/bin/env python3
"""
ROS Custom message listner
"""
import rospy  # the essential rospy import
from incredible_package.msg import AGoodMessage  # custom message import


def callback(msg):
    """This is a callback that shall handle the incoming message

    Arguments:
        msg {type: AGoodMessage}
        This is the message received from the topic.
        The message type is as defined in the Subscriber class
        constructor (i.e. our custom message).
    """
    """
    The following simply prints the message contents
    with some additional text. The "format" method of a string
    simply fills out each of the "{}" with the provided variables.
    You can put some formating or order information into the braces.
    Search for Python string formating for more information.
    """
    rospy.loginfo('Received a message at {}. Message:\
        "{}" and a random number: {}'.format(
        msg.header.stamp.secs, msg.message,
        msg.number
    ))


if __name__ == '__main__':
    rospy.init_node('listener')  # initialize the node with name "listener"
    """
    As with the publisher, set topic name and message type.
    Additionally, we need to specify a callback function for when
    a message is received.
    """
    listener = rospy.Subscriber('messages',
                                AGoodMessage, callback)
    rospy.spin()  # hold the execution here and periodically check for messages
