#!/usr/bin/env python3
"""
ROS service provider
"""
import rospy
import numpy as np
"""
Following is an import of our custom service definition.
It is similar to importing a message.
When we define a service with name <some_service>,
three definitions will be automaticall generated (after
running "catkin build"):
<some_service>
    - the base service definition
<some_service>Request
    - definition of the request message, i.e. what is
    sent by the service caller
<some_service>Response
    - definition of the response message, i.e. what is
    sent back by the service provider
The base service definition has to be imported always,
however, the request and response definitions are needed
only if you are going to use them.
In this case, we are not using the request part of the service,
thus it is not imported.
"""
from incredible_package.srv import Random, RandomResponse

def randGen(request):
    """This function handler the service request.

    Arguments:
        request {type: RandomRequest}
    Returns:
        type: RandomResponse
        - this is the message we want to send back as response
        to the service call. It is an actual message,
        thus anything that applied to standard messsages
        applies here as well.
    """
    randNumber = np.random.randint(256)
    rospy.loginfo('Somebody called me and I sent'
              'this number: {}'.format(randNumber))
    # we are providing the random number directly into the message constructor
    return RandomResponse(randNumber)

if __name__ == "__main__":
	rospy.init_node('random_server')  # initialize the node
    # create service instance with service name, type, and request handler (function)
	s = rospy.Service('generate_number', Random, randGen)
	rospy.spin()
